@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_apigatewayv2._jsii
@@ -20,9 +20,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-serverless-lamp",
-    "1.4.9",
+    "1.4.14",
     __name__[0:-6],
-    "cdk-serverless-lamp@1.4.9.jsii.tgz",
+    "cdk-serverless-lamp@1.4.14.jsii.tgz",
 )
 
 __all__ = [
